@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from django.conf.urls import patterns, include, url
-from shiori.bookmark.feeds import LatestEntries
+from shiori.bookmark.feed_generator import LatestEntries
 
 
 urlpatterns = patterns('shiori.bookmark.views',
@@ -13,4 +13,5 @@ urlpatterns = patterns('shiori.bookmark.views',
                        url(r'^tags$', 'tags'),
                        url(r'^tags/(?P<tag_id>[\w.]+)$', 'tag'),
                        url(r'^feeds$', LatestEntries()),
+                       url(r'^feed_subscription$', 'feed_subscription'),
                        url(r'^b/(?P<bookmark_id>[\w.]+)$', 'bookmark'),)
